#!/usr/bin/env python
import keyword_rename
keyword_rename._in(1)
keyword_rename._in(_except=1)
keyword_rename._except(1)
keyword_rename._except(_in=1)
